@@ -5,7 +5,7 @@ from decimal import Decimal
 from datetime import datetime
 from trading_sdk.types import Side
 
-OrderStatus = Literal['NEW', 'PARTIALLY_FILLED', 'FILLED', 'CANCELED', 'PARTIALLY_CANCELED']
+OrderStatus = Literal['NEW', 'PARTIALLY_FILLED', 'FILLED', 'CANCELED', 'PARTIALLY_CANCELED', 'UNTRIGGERED']
 
 @dataclass
 class OrderState:
